@@ -3,7 +3,7 @@
  * transmit.h
  *	  Shared declarations for transmitting files between remote nodes.
  *
- * Copyright (c) 2012-2016, Citus Data, Inc.
+ * Copyright (c) Citus Data, Inc.
  *
  *-------------------------------------------------------------------------
  */
@@ -11,15 +11,17 @@
 #ifndef TRANSMIT_H
 #define TRANSMIT_H
 
+#include "c.h"
+
 #include "lib/stringinfo.h"
+#include "nodes/parsenodes.h"
+#include "storage/fd.h"
 
 
 /* Function declarations for transmitting files between two nodes */
-extern void ReceiveRegularFile(const char *filename);
+extern void RedirectCopyDataToRegularFile(const char *filename);
 extern void SendRegularFile(const char *filename);
-
-/* Function declaration local to commands and worker modules */
-extern void FreeStringInfo(StringInfo stringInfo);
+extern File FileOpenForTransmit(const char *filename, int fileFlags, int fileMode);
 
 
 #endif   /* TRANSMIT_H */
