@@ -2,9 +2,6 @@
 -- MULTI_TPCH_QUERY7
 --
 
--- Change configuration to treat lineitem AND orders tables as large
-
-SET citus.large_table_shard_count TO 2;
 
 -- Query #7 from the TPC-H decision support benchmark
 
